![logo](/docs/la_black_luna.png)

# Estoult

[![PyPI](https://img.shields.io/pypi/v/estoult)](https://pypi.org/project/estoult/)
[![Documentation Status](https://readthedocs.org/projects/estoult/badge/?version=latest)](https://estoult.readthedocs.io/en/latest/?badge=latest)

Estoult is a Python toolkit for data mapping with an integrated query builder for SQL databases. It currently supports MySQL, PostgreSQL, and SQLite.

Features:

- Not an ORM. Estoult doesn't attempt to apply relational algebra to objects.
- Concise and composable (sub)queries.
- Easy debugging by displaying any generated SQL in a readable format.
- Performant as raw SQL. Estoult is **NOT** an ORM.

Estoult only works with Python 3.6+.

## Installation

Install Estoult through pip:

```
pip install estoult
```

## Documentation

Check the [documentation](https://estoult.readthedocs.io/en/latest/) for help.

## License

Estoult is licensed under the MIT license (see [LICENSE file](/LICENSE)).
